@@ -1,4 +1,4 @@
-/* Decoder8859_2.java -- Decoder for ISO-Latin-2 Character set
+/* Decoder8859_5.java -- Decoder for ISO-Latin-5 Character set
    Copyright (C) 1998 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
@@ -41,13 +41,13 @@ package gnu.java.io.decode;
 import java.io.InputStream;
 
 /**
-  * This class decodes bytes in ISO-8859-2 (Latin-2) format to Unicode.
+  * This class decodes bytes in ISO-8859-3 (Latin-3) format to Unicode.
   *
   * @version 0.0
   *
   * @author Aaron M. Renn (arenn@urbanophile.com)
   */
-public class Decoder8859_2 extends DecoderEightBitLookup
+public class Decoder8859_5 extends DecoderEightBitLookup
 {
 
 /*************************************************************************/
@@ -56,8 +56,8 @@ public class Decoder8859_2 extends DecoderEightBitLookup
   * This is the lookup table for this encoding
   */
 
-protected static char[] lookup_table_8859_2 = { 
-// Start of range undefined in the spec file I used.
+protected static char[] lookup_table_8859_5 = { 
+// Begin range undefined in spec document I used
 0x0000,
 0x0001,
 0x0002,
@@ -90,7 +90,7 @@ protected static char[] lookup_table_8859_2 = {
 0x001D,
 0x001E,
 0x001F,
-// End of range undefined in spec file I used.
+// End range undefined in spec document I used
 0x0020,
 0x0021,
 0x0022,
@@ -186,7 +186,7 @@ protected static char[] lookup_table_8859_2 = {
 0x007C,
 0x007D,
 0x007E,
-// Begin range undefined in spec file I used
+// Begin range undefined in spec document I used
 0x007F,
 0x0080,
 0x0081,
@@ -220,110 +220,110 @@ protected static char[] lookup_table_8859_2 = {
 0x009D,
 0x009E,
 0x009F,
-// End range undefined in spec file I used
+// End range undefined in spec document I used
 0x00A0,
-0x0104,
-0x02D8,
-0x0141,
-0x00A4,
-0x013D,
-0x015A,
-0x00A7,
-0x00A8,
-0x0160,
-0x015E,
-0x0164,
-0x0179,
+0x0401,
+0x0402,
+0x0403,
+0x0404,
+0x0405,
+0x0406,
+0x0407,
+0x0408,
+0x0409,
+0x040A,
+0x040B,
+0x040C,
 0x00AD,
-0x017D,
-0x017B,
-0x00B0,
-0x0105,
-0x02DB,
-0x0142,
-0x00B4,
-0x013E,
-0x015B,
-0x02C7,
-0x00B8,
-0x0161,
-0x015F,
-0x0165,
-0x017A,
-0x02DD,
-0x017E,
-0x017C,
-0x0154,
-0x00C1,
-0x00C2,
-0x0102,
-0x00C4,
-0x0139,
-0x0106,
-0x00C7,
-0x010C,
-0x00C9,
-0x0118,
-0x00CB,
-0x011A,
-0x00CD,
-0x00CE,
-0x010E,
-0x0110,
-0x0143,
-0x0147,
-0x00D3,
-0x00D4,
-0x0150,
-0x00D6,
-0x00D7,
-0x0158,
-0x016E,
-0x00DA,
-0x0170,
-0x00DC,
-0x00DD,
-0x0162,
-0x00DF,
-0x0155,
-0x00E1,
-0x00E2,
-0x0103,
-0x00E4,
-0x013A,
-0x0107,
-0x00E7,
-0x010D,
-0x00E9,
-0x0119,
-0x00EB,
-0x011B,
-0x00ED,
-0x00EE,
-0x010F,
-0x0111,
-0x0144,
-0x0148,
-0x00F3,
-0x00F4,
-0x0151,
-0x00F6,
-0x00F7,
-0x0159,
-0x016F,
-0x00FA,
-0x0171,
-0x00FC,
-0x00FD,
-0x0163,
-0x02D9
+0x040E,
+0x040F,
+0x0410,
+0x0411,
+0x0412,
+0x0413,
+0x0414,
+0x0415,
+0x0416,
+0x0417,
+0x0418,
+0x0419,
+0x041A,
+0x041B,
+0x041C,
+0x041D,
+0x041E,
+0x041F,
+0x0420,
+0x0421,
+0x0422,
+0x0423,
+0x0424,
+0x0425,
+0x0426,
+0x0427,
+0x0428,
+0x0429,
+0x042A,
+0x042B,
+0x042C,
+0x042D,
+0x042E,
+0x042F,
+0x0430,
+0x0431,
+0x0432,
+0x0433,
+0x0434,
+0x0435,
+0x0436,
+0x0437,
+0x0438,
+0x0439,
+0x043A,
+0x043B,
+0x043C,
+0x043D,
+0x043E,
+0x043F,
+0x0440,
+0x0441,
+0x0442,
+0x0443,
+0x0444,
+0x0445,
+0x0446,
+0x0447,
+0x0448,
+0x0449,
+0x044A,
+0x044B,
+0x044C,
+0x044D,
+0x044E,
+0x044F,
+0x2116,
+0x0451,
+0x0452,
+0x0453,
+0x0454,
+0x0455,
+0x0456,
+0x0457,
+0x0458,
+0x0459,
+0x045A,
+0x045B,
+0x045C,
+0x00A7,
+0x045E,
+0x045F
 };
 
 static
 {
-  scheme_name = "8859_2";
-  scheme_description = "ISO-8859-2 (Latin-2 character set)";
-  lookup_table = lookup_table_8859_2;
+  scheme_name = "8859_5";
+  scheme_description = "ISO-8859-5 (Latin-5 character set)";
+  lookup_table = lookup_table_8859_5;
 }
 
 /*************************************************************************/
@@ -332,10 +332,10 @@ static
  * Constructors
  */
 public
-Decoder8859_2(InputStream in)
+Decoder8859_5(InputStream in)
 {
   super(in);
 }
 
-} // class Decoder8859_2
+} // class Decoder8859_5
 
