@@ -1,4 +1,4 @@
-/* Encoder8859_1.java -- Encoder for ISO-Latin-1 Character set
+/* Encoder8859_5.java -- Encoder for ISO-Latin-5 Character set
    Copyright (C) 1998 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
@@ -41,13 +41,13 @@ package gnu.java.io.encode;
 import java.io.OutputStream;
 
 /**
-  * This class encode Unicode chars in ISO-8859-1 (Latin-1) format.
+  * This class decodes bytes in ISO-8859-3 (Latin-3) format to Unicode.
   *
   * @version 0.0
   *
   * @author Aaron M. Renn (arenn@urbanophile.com)
   */
-public class Encoder8859_1 extends EncoderEightBitLookup
+public class Encoder8859_5 extends EncoderEightBitLookup
 {
 
 /*************************************************************************/
@@ -56,7 +56,8 @@ public class Encoder8859_1 extends EncoderEightBitLookup
   * This is the lookup table for this encoding
   */
 
-protected static char[] lookup_table_8859_1 = { 
+protected static char[] lookup_table_8859_5 = { 
+// Begin range undefined in spec document I used
 0x0000,
 0x0001,
 0x0002,
@@ -89,6 +90,7 @@ protected static char[] lookup_table_8859_1 = {
 0x001D,
 0x001E,
 0x001F,
+// End range undefined in spec document I used
 0x0020,
 0x0021,
 0x0022,
@@ -184,6 +186,7 @@ protected static char[] lookup_table_8859_1 = {
 0x007C,
 0x007D,
 0x007E,
+// Begin range undefined in spec document I used
 0x007F,
 0x0080,
 0x0081,
@@ -217,111 +220,110 @@ protected static char[] lookup_table_8859_1 = {
 0x009D,
 0x009E,
 0x009F,
+// End range undefined in spec document I used
 0x00A0,
-0x00A1,
-0x00A2,
-0x00A3,
-0x00A4,
-0x00A5,
-0x00A6,
-0x00A7,
-0x00A8,
-0x00A9,
-0x00AA,
-0x00AB,
-0x00AC,
+0x0401,
+0x0402,
+0x0403,
+0x0404,
+0x0405,
+0x0406,
+0x0407,
+0x0408,
+0x0409,
+0x040A,
+0x040B,
+0x040C,
 0x00AD,
-0x00AE,
-0x00AF,
-0x00B0,
-0x00B1,
-0x00B2,
-0x00B3,
-0x00B4,
-0x00B5,
-0x00B6,
-0x00B7,
-0x00B8,
-0x00B9,
-0x00BA,
-0x00BB,
-0x00BC,
-0x00BD,
-0x00BE,
-0x00BF,
-0x00C0,
-0x00C1,
-0x00C2,
-0x00C3,
-0x00C4,
-0x00C5,
-0x00C6,
-0x00C7,
-0x00C8,
-0x00C9,
-0x00CA,
-0x00CB,
-0x00CC,
-0x00CD,
-0x00CE,
-0x00CF,
-0x00D0,
-0x00D1,
-0x00D2,
-0x00D3,
-0x00D4,
-0x00D5,
-0x00D6,
-0x00D7,
-0x00D8,
-0x00D9,
-0x00DA,
-0x00DB,
-0x00DC,
-0x00DD,
-0x00DE,
-0x00DF,
-0x00E0,
-0x00E1,
-0x00E2,
-0x00E3,
-0x00E4,
-0x00E5,
-0x00E6,
-0x00E7,
-0x00E8,
-0x00E9,
-0x00EA,
-0x00EB,
-0x00EC,
-0x00ED,
-0x00EE,
-0x00EF,
-0x00F0,
-0x00F1,
-0x00F2,
-0x00F3,
-0x00F4,
-0x00F5,
-0x00F6,
-0x00F7,
-0x00F8,
-0x00F9,
-0x00FA,
-0x00FB,
-0x00FC,
-0x00FD,
-0x00FE,
-0x00FF
+0x040E,
+0x040F,
+0x0410,
+0x0411,
+0x0412,
+0x0413,
+0x0414,
+0x0415,
+0x0416,
+0x0417,
+0x0418,
+0x0419,
+0x041A,
+0x041B,
+0x041C,
+0x041D,
+0x041E,
+0x041F,
+0x0420,
+0x0421,
+0x0422,
+0x0423,
+0x0424,
+0x0425,
+0x0426,
+0x0427,
+0x0428,
+0x0429,
+0x042A,
+0x042B,
+0x042C,
+0x042D,
+0x042E,
+0x042F,
+0x0430,
+0x0431,
+0x0432,
+0x0433,
+0x0434,
+0x0435,
+0x0436,
+0x0437,
+0x0438,
+0x0439,
+0x043A,
+0x043B,
+0x043C,
+0x043D,
+0x043E,
+0x043F,
+0x0440,
+0x0441,
+0x0442,
+0x0443,
+0x0444,
+0x0445,
+0x0446,
+0x0447,
+0x0448,
+0x0449,
+0x044A,
+0x044B,
+0x044C,
+0x044D,
+0x044E,
+0x044F,
+0x2116,
+0x0451,
+0x0452,
+0x0453,
+0x0454,
+0x0455,
+0x0456,
+0x0457,
+0x0458,
+0x0459,
+0x045A,
+0x045B,
+0x045C,
+0x00A7,
+0x045E,
+0x045F
 };
 
 static
 {
-  scheme_name = "8859_1";
-  scheme_description = "ISO-8859-1 (Latin-1 character set)";
-  lookup_table = lookup_table_8859_1;
-  EncoderEightBitLookup.loadTable();
-  // FIXME explicit super class is workaround for jikes1.15a and orp 1.0.9
+  scheme_name = "8859_5";
+  scheme_description = "ISO-8859-5 (Latin-5 character set)";
+  lookup_table = lookup_table_8859_5;
 }
 
 /*************************************************************************/
@@ -330,10 +332,10 @@ static
  * Constructors
  */
 public
-Encoder8859_1(OutputStream out)
+Encoder8859_5(OutputStream out)
 {
   super(out);
 }
 
-} // class Encoder8859_1
+} // class Encoder8859_5
 
