@@ -237,12 +237,15 @@ Frame(String title)
 {
   super();
   this.title = title;
+  // Top-level frames are initially invisible.
+  visible = false;
 }
 
 public
 Frame(GraphicsConfiguration gc)
 {
   super(gc);
+  visible = false;
 }
 
 public
@@ -250,6 +253,7 @@ Frame(String title, GraphicsConfiguration gc)
 {
   super(gc);
   setTitle(title);
+  visible = false;
 }
 
 /*************************************************************************/
@@ -433,25 +437,6 @@ addNotify()
 
 /*************************************************************************/
 
-/**
-  * Destroys any resources associated with this frame.  This includes
-  * all components in the frame and all owned toplevel windows.
-  */
-public void
-dispose()
-{
-  Enumeration e = ownedWindows.elements();
-  while(e.hasMoreElements())
-    {
-      Window w = (Window)e.nextElement();
-      w.dispose();
-    }
-
-  super.dispose();
-}
-
-/*************************************************************************/
-
 /**
   * Returns a debugging string describing this window.
   *
@@ -468,8 +453,6 @@ getFrames()
 {
   //Frame[] array = new Frames[frames.size()];
   //return frames.toArray(array);
-    
-    // see finalize() comment
   String msg = "FIXME: can't be implemented without weak references";
   throw new UnsupportedOperationException(msg);
 }
