@@ -90,6 +90,9 @@ public class File implements Serializable, Comparable
    * is taken from the <code>path.separator</code> system property.
    */
   public static final char pathSeparatorChar = pathSeparator.charAt(0);
+
+  // FIXME: We support only caseSensitive filesystems currently.
+  static boolean caseSensitive = true;
   
   static
   {
@@ -142,10 +145,10 @@ public class File implements Serializable, Comparable
    * @exception SecurityException If the <code>SecurityManager</code> 
    * does not allow access to the file
    */
-  public boolean canRead ()
+  public boolean canRead()
   {
     // Test for existence. This also does the SecurityManager check
-    if (!exists ())
+    if (!exists())
       return false;
 
     return canReadInternal (path);
@@ -165,11 +168,11 @@ public class File implements Serializable, Comparable
    * @exception SecurityException If the <code>SecurityManager</code> 
    * does not allow access to the file
    */
-  public boolean canWrite ()
+  public boolean canWrite()
   {
     // We still need to do a SecurityCheck since exists() only checks
     // for read access
-    checkWrite ();
+    checkWrite();
      
     // Test for existence.  This is required by the spec
     if (!exists())
@@ -188,7 +191,7 @@ public class File implements Serializable, Comparable
           */
           String filename = (separatorChar!='\\')?"test-dir-write":"tst";
   	  File test = createTempFile (filename, null, this);
-  	  return (test != null && test.delete ());
+  	  return (test != null && test.delete());
         }
       catch (IOException ioe)
         {
@@ -215,8 +218,8 @@ public class File implements Serializable, Comparable
    */
   public boolean createNewFile() throws IOException
   {
-    checkWrite ();
-    return createInternal (getPath ());
+    checkWrite();
+    return createInternal (path);
   }
  
   /*
@@ -233,9 +236,9 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If deleting of the file is not allowed
    */
-  public synchronized boolean delete ()
+  public synchronized boolean delete()
   {
-    SecurityManager s = System.getSecurityManager ();
+    SecurityManager s = System.getSecurityManager();
     
     if (s != null)
       s.checkDelete (path);
@@ -260,15 +263,15 @@ public class File implements Serializable, Comparable
    */
   public boolean equals (Object obj)
   {
-    if (obj == null)
+    if (! (obj instanceof File))
       return false;
     
-    if (!(obj instanceof File))
-      return false;
+    File other = (File) obj;
 
-    File f = (File) obj;
-
-    return f.getPath ().equals (getPath ());
+    if (caseSensitive)
+      return path.equals (other.path);
+    else
+      return path.equalsIgnoreCase (other.path);
   }
 
   /*
@@ -284,9 +287,9 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If reading of the file is not permitted
    */
-  public boolean exists ()
+  public boolean exists()
   {
-    checkRead ();
+    checkRead();
     return existsInternal (path);
   }
 
@@ -346,7 +349,7 @@ public class File implements Serializable, Comparable
         directory = new File(dirname);
       }
 
-    String dirpath = directory.getPath();
+    String dirpath = directory.path;
     if (PlatformHelper.isRootDirectory(dirpath))
       path = dirpath + name;
     else
@@ -362,9 +365,9 @@ public class File implements Serializable, Comparable
    *
    * @return The absolute path of this file
    */
-  public String getAbsolutePath ()
+  public String getAbsolutePath()
   {
-    if (isAbsolute ())
+    if (isAbsolute())
       return path;
     
     String dir = System.getProperty ("user.dir");
@@ -385,7 +388,7 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2
    */
-  public File getAbsoluteFile ()
+  public File getAbsoluteFile()
   {
     return new File (getAbsolutePath());
   }
@@ -403,7 +406,7 @@ public class File implements Serializable, Comparable
    *
    * @exception IOException If an error occurs
    */
-  public String getCanonicalPath () throws IOException
+  public String getCanonicalPath() throws IOException
   {
     String abspath = getAbsolutePath();
     return PlatformHelper.toCanonicalForm(abspath);
@@ -420,7 +423,7 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2
    */
-  public File getCanonicalFile () throws IOException
+  public File getCanonicalFile() throws IOException
   {
     return new File (getCanonicalPath());
   }
@@ -432,7 +435,7 @@ public class File implements Serializable, Comparable
    *
    * @return The file name
    */
-  public String getName ()
+  public String getName()
   {
     int pos = PlatformHelper.lastIndexOfSeparator (path);
     if (pos == -1)
@@ -441,7 +444,7 @@ public class File implements Serializable, Comparable
     if (PlatformHelper.endWithSeparator (path))
       return "";
 
-    return path.substring (pos + separator.length ());
+    return path.substring (pos + separator.length());
   }
 
   /**
@@ -451,7 +454,7 @@ public class File implements Serializable, Comparable
    *
    * @return The parent directory of this file
    */
-  public String getParent ()
+  public String getParent()
   {
     if (PlatformHelper.isRootDirectory (path))
       return null;
@@ -475,13 +478,10 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2
    */
-  public File getParentFile ()
+  public File getParentFile()
   {
-    String parent = getParent ();
-    if (parent == null)
-      return null;
-
-    return new File (parent);
+    String parent = getParent();
+    return parent != null ? new File (parent) : null;
   }
 
   /**
@@ -490,7 +490,7 @@ public class File implements Serializable, Comparable
    *
    * @return The pathname of this file
    */
-  public String getPath ()
+  public String getPath()
   {
     return path;
   }
@@ -502,9 +502,12 @@ public class File implements Serializable, Comparable
    *
    * @return The hash code for this object
    */
-  public int hashCode ()
+  public int hashCode()
   {
-    return getPath().hashCode() ^ 1234321;
+    if (caseSensitive)
+      return path.hashCode() ^ 1234321;
+    else
+      return path.toLowerCase().hashCode() ^ 1234321;
   }
 
   /**
@@ -516,7 +519,7 @@ public class File implements Serializable, Comparable
    * @return <code>true</code> if this object represents an absolute 
    * file name, <code>false</code> otherwise.
    */
-  public boolean isAbsolute ()
+  public boolean isAbsolute()
   {
     if (PlatformHelper.beginWithRootPathPrefix (path) > 0)
       return true;
@@ -534,9 +537,9 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If reading of the file is not permitted
    */
-  public boolean isDirectory ()
+  public boolean isDirectory()
   {
-    checkRead ();
+    checkRead();
     return isDirectoryInternal (path); 
   }
 
@@ -550,9 +553,9 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If reading of the file is not permitted
    */
-  public boolean isFile ()
+  public boolean isFile()
   {
-    checkRead ();
+    checkRead();
     return isFileInternal (path);
   }
 
@@ -567,7 +570,7 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2
    */
-  public boolean isHidden ()
+  public boolean isHidden()
   {
     // FIXME: this only works on UNIX
     if (getName().startsWith("."))
@@ -596,9 +599,9 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If reading of the file is not permitted
    */
-  public long lastModified ()
+  public long lastModified()
   {
-    checkRead ();
+    checkRead();
     return lastModifiedInternal (path);
   }
 
@@ -616,9 +619,9 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If reading of the file is not permitted
    */
-  public long length ()
+  public long length()
   {
-    checkRead ();
+    checkRead();
     return lengthInternal (path);
   }
 
@@ -657,7 +660,7 @@ public class File implements Serializable, Comparable
    */
   public String[] list (FilenameFilter filter)
   {
-    checkRead ();
+    checkRead();
 
     // Get the list of files
     String list_path = PlatformHelper.removeTailSeparator(path);
@@ -709,7 +712,7 @@ public class File implements Serializable, Comparable
    * @exception SecurityException If read access is not allowed to the 
    * directory by the <code>SecurityManager</code>
    */
-  public String[] list ()
+  public String[] list()
   {
     return list (null);
   }
@@ -732,7 +735,7 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2
    */
-  public File[] listFiles ()
+  public File[] listFiles()
   {
     return listFiles ((FilenameFilter) null);
   }
@@ -833,7 +836,7 @@ public class File implements Serializable, Comparable
    *
    * @return A <code>String</code> representation of this file
    */
-  public String toString ()
+  public String toString()
   {
     return path;
   }
@@ -848,13 +851,13 @@ public class File implements Serializable, Comparable
    * @exception MalformedURLException If the URL cannot be created 
    * successfully.
    */
-  public URL toURL () throws MalformedURLException
+  public URL toURL() throws MalformedURLException
   {
-    String abspath = getAbsolutePath ();
+    String abspath = getAbsolutePath();
     
     try
       {
-        if (new File (abspath).isDirectory ())
+        if (new File (abspath).isDirectory())
   	  abspath = abspath + separator;
       }
     catch(Exception _) { }
@@ -877,9 +880,9 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If write access is not allowed to this file
    */
-  public boolean mkdir ()
+  public boolean mkdir()
   {
-    checkWrite ();
+    checkWrite();
     String mk_path = PlatformHelper.removeTailSeparator (path);
     return mkdirInternal (mk_path);
   }
@@ -893,7 +896,7 @@ public class File implements Serializable, Comparable
    *
    * @exception SecurityException If write access is not allowed to this file
    */
-  public boolean mkdirs ()
+  public boolean mkdirs()
   {
     String parent = getParent();
     if (parent == null)
@@ -909,7 +912,7 @@ public class File implements Serializable, Comparable
           return false;
       }
 
-    return mkdir ();
+    return mkdir();
   }
 
   /**
@@ -959,17 +962,17 @@ public class File implements Serializable, Comparable
           throw new IOException ("Cannot determine system temporary directory"); 
 	
         directory = new File (dirname);
-        if (!directory.exists ())
+        if (!directory.exists())
           throw new IOException ("System temporary directory "
-                                 + directory.getName () + " does not exist.");
-        if (!directory.isDirectory ())
+                                 + directory.getName() + " does not exist.");
+        if (!directory.isDirectory())
           throw new IOException ("System temporary directory "
-                                 + directory.getName ()
+                                 + directory.getName()
                                  + " is not really a directory.");
       }
 
     // Check if prefix is at least 3 characters long
-    if (prefix.length () < 3)
+    if (prefix.length() < 3)
       throw new IllegalArgumentException ("Prefix too short: " + prefix);
 
     // Set default value of suffix
@@ -989,10 +992,10 @@ public class File implements Serializable, Comparable
         // probably a non-DOS-filesystem, use long names
         do
           {
-            String filename = prefix + System.currentTimeMillis () + suffix;
+            String filename = prefix + System.currentTimeMillis() + suffix;
             file = new File (directory, filename);
           }
-        while (file.exists ());
+        while (file.exists());
       }
     else
       {
@@ -1009,7 +1012,7 @@ public class File implements Serializable, Comparable
             String filename = prefix + java.lang.Integer.toHexString(n) + suffix;
             file = new File(directory, filename);
           }
-        while (file.exists ());
+        while (file.exists());
       }
 
     // Verify that we are allowed to create this file
@@ -1041,15 +1044,15 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2
    */
-  public boolean setReadOnly ()
+  public boolean setReadOnly()
   {
     // Test for existence.
-    if (!exists ())
+    if (!exists())
       return false;
 
     // We still need to do a SecurityCheck since exists() only checks
     // for read access
-    checkWrite ();
+    checkWrite();
     return setReadOnlyInternal (path);
   }
 
@@ -1064,7 +1067,7 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2
    */
-  public static File[] listRoots ()
+  public static File[] listRoots()
   {
     File[] f = new File[1];
     f[0] = new File("/");
@@ -1127,8 +1130,8 @@ public class File implements Serializable, Comparable
     
     try
       {  
-        p1 = getCanonicalPath ();
-        p2 = other.getCanonicalPath ();
+        p1 = getCanonicalPath();
+        p2 = other.getCanonicalPath();
       }
     catch(IOException e)
       {
@@ -1187,9 +1190,9 @@ public class File implements Serializable, Comparable
    */
   public synchronized boolean renameTo (File dest)
   {
-    checkWrite ();
+    checkWrite();
     // Call our native rename method
-    return renameToInternal (path, dest.getPath ());
+    return renameToInternal (path, dest.path);
   }
 
   /*
@@ -1218,23 +1221,23 @@ public class File implements Serializable, Comparable
     if (time < 0)
       throw new IllegalArgumentException("Negative modification time: " + time);
 
-    checkWrite ();
+    checkWrite();
     return setLastModifiedInternal (path, time);
   }
 
-  private void checkWrite ()
+  private void checkWrite()
   {
     // Check the SecurityManager
-    SecurityManager s = System.getSecurityManager ();
+    SecurityManager s = System.getSecurityManager();
     
     if (s != null)
       s.checkWrite (path);
   }
 
-  private void checkRead ()
+  private void checkRead()
   {
     // Check the SecurityManager
-    SecurityManager s = System.getSecurityManager ();
+    SecurityManager s = System.getSecurityManager();
     
     if (s != null)
       s.checkRead (path);
@@ -1250,12 +1253,12 @@ public class File implements Serializable, Comparable
    *
    * @since 1.2 
    */
-  public void deleteOnExit ()
+  public void deleteOnExit()
   {
     // Check the SecurityManager
-    SecurityManager sm = System.getSecurityManager ();
+    SecurityManager sm = System.getSecurityManager();
     if (sm != null)
-      sm.checkDelete(path);
+      sm.checkDelete (path);
 
     // Sounds like we need to do some VM specific stuff here. We could delete
     // the file in finalize() and set FinalizeOnExit to true, but delete on
@@ -1267,21 +1270,22 @@ public class File implements Serializable, Comparable
 
   private void writeObject (ObjectOutputStream oos) throws IOException
   {
-    oos.defaultWriteObject ();
+    oos.defaultWriteObject();
     oos.writeChar (separatorChar);
   }
 
   private void readObject (ObjectInputStream ois)
     throws ClassNotFoundException, IOException
   {
-    ois.defaultReadObject ();
+    ois.defaultReadObject();
 
     // If the file was from an OS with a different dir separator,
     // fixup the path to use the separator on this OS.
-    char oldSeparatorChar = ois.readChar ();
+    char oldSeparatorChar = ois.readChar();
     
     if (oldSeparatorChar != separatorChar)
       path = path.replace (oldSeparatorChar, separatorChar);
   }
+  
 } // class File
 
