@@ -1,5 +1,5 @@
 /* ServerSocket.java -- Class for implementing server side sockets
-   Copyright (C) 1998, 1999, 2000, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1998, 1999, 2000, 2002, 2003 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -35,8 +35,10 @@ this exception to your version of the library, but you are not
 obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version. */
 
+
 package java.net;
 
+import gnu.java.net.PlainSocketImpl;
 import java.io.IOException;
 import java.nio.channels.IllegalBlockingModeException;
 import java.nio.channels.ServerSocketChannel;
@@ -71,13 +73,28 @@ public class ServerSocket
    */
   private SocketImpl impl;
 
-  /**
-   * ServerSocketChannel of this ServerSocket. This channel only exists
-   * when the socket is created by ServerSocketChannel.open().
-   */
-  private ServerSocketChannel ch;
-
   private boolean closed = false;
+
+  /*
+   * This constructor is only used by java.nio.
+   */
+  // FIXME: Workaround a bug in gcj.
+  //ServerSocket (PlainSocketImpl impl) throws IOException
+  ServerSocket (SocketImpl impl) throws IOException
+  {
+    this.impl = impl;
+    this.impl.create (true);
+  }
+
+  /*
+   * This method is only used by java.nio.
+   */
+  // FIXME: Workaround a bug in gcj.
+  //PlainSocketImpl getImpl()
+  SocketImpl getImpl()
+  {
+    return impl;
+  }
   
   /**
    * Constructor that simply sets the implementation.
@@ -158,14 +175,6 @@ public class ServerSocket
     bind (new InetSocketAddress (bindAddr, port), backlog);
   }
 
-  /*
-   * This method may only be used by java.nio.channels.ServerSocketChannel.open.
-   */
-  void setChannel (ServerSocketChannel ch)
-  {
-    this.ch = ch;
-  }
-
   /**
    * Binds the server socket to a specified socket address
    *
@@ -316,7 +325,8 @@ public class ServerSocket
   protected final void implAccept (Socket s)
     throws IOException
   {
-    if (ch != null && !ch.isBlocking())
+    if (getChannel() != null
+        && !getChannel().isBlocking())
       throw new IllegalBlockingModeException();
 	    
     impl.accept(s.impl);
@@ -332,8 +342,8 @@ public class ServerSocket
     if (impl != null)
       impl.close ();
 
-    if (ch != null)
-      ch.close ();
+    if (getChannel() != null)
+      getChannel().close ();
     
     closed = true;
   }
@@ -349,7 +359,7 @@ public class ServerSocket
    */
   public ServerSocketChannel getChannel()
   {
-    return ch;
+    return null;
   }
 
   /**
