@@ -43,10 +43,9 @@ import java.io.IOException;
 import java.io.Serializable;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
-import java.util.Hashtable;
+import java.util.HashMap;
 import java.util.StringTokenizer;
 
-
 /*
  * Written using on-line Java Platform 1.2 API Specification, as well
  * as "The Java Class Libraries", 2nd edition (Addison-Wesley, 1998).
@@ -57,7 +56,8 @@ import java.util.StringTokenizer;
   * This final class represents an Internet Uniform Resource Locator (URL).
   * For details on the syntax of URL's and what they can be used for,
   * refer to RFC 1738, available from <a 
-  * href="http://ds.internic.net/rfcs/rfc1738.txt">http://ds.internic.net/rfcs/rfc1738.txt</a>
+  * href="http://ds.internic.net/rfcs/rfc1738.txt">
+  * http://ds.internic.net/rfcs/rfc1738.txt</a>
   * <p>
   * There are a great many protocols supported by URL's such as "http",
   * "ftp", and "file".  This object can handle any arbitrary URL for which
@@ -74,10 +74,10 @@ import java.util.StringTokenizer;
   * If this property is set, it is assumed to be a "|" separated list of
   * package names in which to attempt locating protocol handlers.  The
   * protocol handler is searched for by appending the string 
-  * ".<protocol>.Handler" to each packed in the list until a hander is found.
-  * If a protocol handler is not found in this list of packages, or if the
-  * property does not exist, then the default protocol handler of
-  * "gnu.java.net.<protocol>.Handler" is tried.  If this is
+  * ".&lt;protocol&gt;.Handler" to each packed in the list until a hander is
+  * found. If a protocol handler is not found in this list of packages, or if
+  * the property does not exist, then the default protocol handler of
+  * "gnu.java.net.&lt;protocol&gt;.Handler" is tried.  If this is
   * unsuccessful, a MalformedURLException is thrown.
   * <p>
   * All of the constructor methods of URL attempt to load a protocol
@@ -119,6 +119,9 @@ import java.util.StringTokenizer;
   */
 public final class URL implements Serializable
 {
+  private static final String DEFAULT_SEARCH_PATH =
+    "gnu.java.net.protocol|sun.net.www.protocol";
+  
   /**
    * The name of the protocol for this URL.
    * The protocol is always stored in lower case.
@@ -174,33 +177,21 @@ public final class URL implements Serializable
    * This a table where we cache protocol handlers to avoid the overhead
    * of looking them up each time.
    */
-  private static Hashtable ph_cache = new Hashtable();
+  private static HashMap ph_cache = new HashMap();
 
   /**
    * Whether or not to cache protocol handlers.
    */
   private static boolean cache_handlers;
 
-  /**
-   * The search path of packages to search for protocol handlers in.
-   */
-  private static String ph_search_path;
-
   static
     {
-      String s = System.getProperty("gnu.java.net.nocache_protocol_handlers");
+      String s = System.getProperty ("gnu.java.net.nocache_protocol_handlers");
+      
       if (s == null)
         cache_handlers = true;
       else
         cache_handlers = false;
-
-      ph_search_path = System.getProperty("java.protocol.handler.pkgs");
-
-      // Tack our default package on at the ends
-      if (ph_search_path != null)
-        ph_search_path = ph_search_path + "|" + "gnu.java.net.protocol";
-      else
-        ph_search_path = "gnu.java.net.protocol";
     }
 
   /**
@@ -320,7 +311,7 @@ public final class URL implements Serializable
     this((URL) null, spec, (URLStreamHandler) null);
   }
 
-  /*
+  /**
    * This method parses a String representation of a URL within the
    * context of an existing URL.  Principally this means that any
    * fields not present the URL are inheritied from the context URL.
@@ -461,7 +452,7 @@ public final class URL implements Serializable
    */
   public boolean equals (Object obj)
   {
-    if (obj == null || ! (obj instanceof URL))
+    if (! (obj instanceof URL))
       return false;
 
     return ph.equals (this, (URL) obj);
@@ -485,6 +476,10 @@ public final class URL implements Serializable
   /**
    * Gets the contents of this URL
    *
+   * @param classes The allow classes for the content object.
+   *
+   * @return a context object for this URL.
+   *
    * @exception IOException If an error occurs
    */
   public final Object getContent (Class[] classes) throws IOException
@@ -497,6 +492,8 @@ public final class URL implements Serializable
    * Returns the file portion of the URL.
    * Defined as <code>path[?query]</code>.
    * Returns the empty string if there is no file portion.
+   *
+   * @return The filename specified in this URL.
    */
   public String getFile()
   {
@@ -507,6 +504,8 @@ public final class URL implements Serializable
    * Returns the path of the URL. This is the part of the file before any '?'
    * character.
    *
+   * @return The path specified in this URL.
+   * 
    * @since 1.3
    */
   public String getPath()
@@ -517,6 +516,8 @@ public final class URL implements Serializable
 
   /**
    * Returns the authority of the URL
+   *
+   * @return The authority specified in this URL.
    * 
    * @since 1.3
    */
@@ -527,6 +528,8 @@ public final class URL implements Serializable
 
   /**
    * Returns the host of the URL
+   *
+   * @return The host specified in this URL.
    */
   public String getHost()
   {
@@ -550,6 +553,8 @@ public final class URL implements Serializable
   /**
    * Returns the default port of the URL. If the StreamHandler for the URL
    * protocol does not define a default port it returns -1.
+   *
+   * @return The default port of the current protocol.
    */
   public int getDefaultPort()
   {
@@ -558,6 +563,8 @@ public final class URL implements Serializable
 
   /**
    * Returns the protocol of the URL
+   *
+   * @return The specified protocol.
    */
   public String getProtocol()
   {
@@ -601,6 +608,8 @@ public final class URL implements Serializable
 
   /**
    * Returns a hashcode computed by the URLStreamHandler of this URL
+   *
+   * @return The hashcode for this URL.
    */
   public int hashCode()
   {
@@ -616,6 +625,7 @@ public final class URL implements Serializable
    * openConnection() method of the protocol handler
    *
    * @return A URLConnection for this URL
+   *
    * @exception IOException If an error occurs
    */
   public URLConnection openConnection() throws IOException
@@ -627,6 +637,8 @@ public final class URL implements Serializable
    * Opens a connection to this URL and returns an InputStream for reading
    * from that connection
    *
+   * @return An <code>InputStream</code> for this URL.
+   * 
    * @exception IOException If an error occurs
    */
   public final InputStream openStream() throws IOException
@@ -683,6 +695,15 @@ public final class URL implements Serializable
    * that only URLStreamHandlers can modify URL fields. URLs are otherwise
    * constant.
    *
+   * @param protocol The protocol name for this URL.
+   * @param host The hostname or IP address for this URL.
+   * @param port The port number of this URL.
+   * @param authority The authority of this URL.
+   * @param userInfo The user and password (if needed) of this URL.
+   * @param path The "path" portion of this URL.
+   * @param query The query of this URL.
+   * @param ref The anchor portion of this URL.
+   *
    * @since 1.3
    */
   protected void set(String protocol, String host, int port,
@@ -769,61 +790,74 @@ public final class URL implements Serializable
   private static synchronized URLStreamHandler
     getURLStreamHandler (String protocol)
   {
-    URLStreamHandler ph;
+    URLStreamHandler ph = null;
 
-    // First, see if a protocol handler is in our cache
+    // First, see if a protocol handler is in our cache.
     if (cache_handlers)
       {
-        Class cls = (Class)ph_cache.get(protocol);
-        if (cls != null)
-          {
-            try
-              {
-                ph = (URLStreamHandler)cls.newInstance();
-                return(ph);
-              }
-            catch (Exception e) { ; }
-          }
+        if ((ph = (URLStreamHandler) ph_cache.get (protocol)) != null)
+          return ph;
       }
 
     // If a non-default factory has been set, use it to find the protocol.
     if (factory != null)
       {
-        ph = factory.createURLStreamHandler(protocol);
-        if (ph != null)
-          {
-            if (cache_handlers)
-	      ph_cache.put(protocol, ph.getClass());
-
-            return(ph);
-	  }
+	ph = factory.createURLStreamHandler (protocol);
       }
 
-    // Finally loop through our search path looking for a match
-    StringTokenizer st = new StringTokenizer(ph_search_path, "|");
-    while (st.hasMoreTokens())
+    // Non-default factory may have returned null or a factory wasn't set.
+    // Use the default search algorithm to find a handler for this protocol.
+    if (ph == null)
       {
-        String clsname = st.nextToken() + "." + protocol + ".Handler";
-         
-        try
+	// Get the list of packages to check and append our default handler
+	// to it, along with the JDK specified default as a last resort.
+	// Except in very unusual environments the JDK specified one shouldn't
+	// ever be needed (or available).
+	String ph_search_path =
+	  System.getProperty("java.protocol.handler.pkgs");
+
+	// Tack our default package on at the ends.
+	if (ph_search_path != null)
+          ph_search_path += "|" + DEFAULT_SEARCH_PATH;
+	else
+          ph_search_path = DEFAULT_SEARCH_PATH;
+
+	// Finally loop through our search path looking for a match.
+	StringTokenizer pkgPrefix = new StringTokenizer (ph_search_path, "|");
+        
+	do
           {
-            Class cls = Class.forName(clsname); 
-            Object obj = cls.newInstance();
-            if (!(obj instanceof URLStreamHandler))
-              continue;
-            else
-              ph = (URLStreamHandler)obj;
-
-            if (cache_handlers)
-              ph_cache.put(protocol, cls);
-
-            return(ph);
+            String clsName = (pkgPrefix.nextToken() + "."
+			      + protocol + ".Handler");
+         
+            try
+              {
+                Object obj = Class.forName (clsName).newInstance();
+	    
+                if (!(obj instanceof URLStreamHandler))
+                  continue;
+                else
+                  ph = (URLStreamHandler) obj;
+              }
+            catch (Exception e)
+              {
+                // Can't instantiate; handler still null,
+		// go on to next element.
+              }
           }
-        catch (Exception e) { ; }
+	while ((! (ph instanceof URLStreamHandler))
+               && pkgPrefix.hasMoreTokens());
       }
 
-    // Still here, which is bad
-    return null;
+    // Update the hashtable with the new protocol handler.
+    if (ph != null
+        && cache_handlers)
+      if (ph instanceof URLStreamHandler)
+	ph_cache.put (protocol, ph);
+      else
+	ph = null;
+
+    return ph;
   }
 
   private void readObject(ObjectInputStream ois)
