@@ -136,21 +136,21 @@ import java.util.Vector;
  */
 public class RuleBasedCollator extends Collator
 {
-  class CollationElement
+  final class CollationElement
   {
     String char_seq;
     int primary;
     short secondary;
     short tertiary;
 
-    CollationElement(String char_seq, int primary, short secondary, short tertiary)
+    CollationElement (String char_seq, int primary, short secondary, short tertiary)
     {
       this.char_seq = char_seq;
       this.primary = primary;
       this.secondary = secondary;
       this.tertiary = tertiary;
     }
- 
+
   } // inner class CollationElement
 
   /**
@@ -162,7 +162,7 @@ public class RuleBasedCollator extends Collator
    * This is the table of collation element values
    */
   private Object[] ce_table;
-
+  
   /**
    * This method initializes a new instance of <code>RuleBasedCollator</code>
    * with the specified collation rules.  Note that an application normally
@@ -174,40 +174,41 @@ public class RuleBasedCollator extends Collator
    *
    * @exception ParseException If the rule string contains syntax errors.
    */
-  public RuleBasedCollator(String rules) throws ParseException
+  public RuleBasedCollator (String rules) throws ParseException
   {
+    if (rules.equals (""))
+      throw new ParseException ("empty rule set", 0);
+    
     this.rules = rules;
-
-    if (rules.equals(""))
-      throw new IllegalArgumentException("Empty rule set");
-
-    Vector v = new Vector();
+    Vector vec = new Vector();
     boolean ignore_chars = true;
     int primary_seq = 0;
     short secondary_seq = 0;
     short tertiary_seq = 0;
-    StringBuffer sb = new StringBuffer("");
-    for (int i = 0; i < rules.length(); i++)
+    StringBuffer argument = new StringBuffer();
+    int len = rules.length();
+    
+    for (int index = 0; index < len; ++index)
       {
-        char c = rules.charAt(i);
+	char c = rules.charAt (index);
 
-        // Check if it is a whitespace character
-        if (((c >= 0x09) && (c <= 0x0D)) || (c == 0x20))
-          continue;
+	// Just skip whitespace.
+	if (Character.isWhitespace (c))
+	  continue;
 
         // Primary difference
         if (c == '<')
           {
             ignore_chars = false;
-            CollationElement e = new CollationElement(sb.toString(), primary_seq,
-                                                      secondary_seq,
-                                                      tertiary_seq);
+            CollationElement e = new CollationElement (argument.toString(), primary_seq,
+                                                       secondary_seq,
+                                                       tertiary_seq);
             secondary_seq = 0;
             tertiary_seq = 0;
             ++primary_seq;
 
-            v.add(e);
-            sb.setLength(0);
+            vec.add (e);
+            argument.setLength (0);
             continue;
           }
 
@@ -215,16 +216,16 @@ public class RuleBasedCollator extends Collator
         if (c == ';')
           {
             if (primary_seq == 0)
-              throw new ParseException(rules, i);
+              throw new ParseException (rules, index);
 
-            CollationElement e = new CollationElement(sb.toString(), primary_seq,
-                                                      secondary_seq,
-                                                      tertiary_seq);
+            CollationElement e = new CollationElement (argument.toString(), primary_seq,
+                                                       secondary_seq,
+                                                       tertiary_seq);
             ++secondary_seq;
             tertiary_seq = 0;
 
-            v.add(e);
-            sb.setLength(0);
+            vec.add (e);
+            argument.setLength (0);
             continue;
           }
 
@@ -232,15 +233,15 @@ public class RuleBasedCollator extends Collator
         if (c == ',')
           {
             if (primary_seq == 0)
-              throw new ParseException(rules, i);
+              throw new ParseException (rules, index);
 
-            CollationElement e = new CollationElement(sb.toString(), primary_seq,
-                                                      secondary_seq,
-                                                      tertiary_seq);
+            CollationElement e = new CollationElement (argument.toString(), primary_seq,
+                                                       secondary_seq,
+                                                       tertiary_seq);
             ++tertiary_seq;
 
-            v.add(e);
-            sb.setLength(0);
+            vec.add (e);
+            argument.setLength (0);
             continue;
           }
 
@@ -248,13 +249,13 @@ public class RuleBasedCollator extends Collator
         if (c == '=')
           {
             if (primary_seq == 0)
-              throw new ParseException(rules, i);
+              throw new ParseException (rules, index);
 
-            CollationElement e = new CollationElement(sb.toString(), primary_seq,
-                                                      secondary_seq,
-                                                      tertiary_seq);
-            v.add(e);
-            sb.setLength(0);
+            CollationElement e = new CollationElement (argument.toString(), primary_seq,
+                                                       secondary_seq,
+                                                       tertiary_seq);
+            vec.add (e);
+            argument.setLength (0);
             continue;
           }
 
@@ -273,96 +274,34 @@ public class RuleBasedCollator extends Collator
         // See if we are still reading characters to skip
         if (ignore_chars == true)
           {
-            CollationElement e = new CollationElement(c + "", 0, (short)0, 
-                                                      (short)0);
-            v.add(e);
+            CollationElement e = new CollationElement (c + "", 0, (short)0, 
+                                                       (short)0);
+            vec.add(e);
             continue;
           }
 
-        sb.append(c);
+        argument.append (c);
       }
 
-    if (sb.length() > 0)
+    if (argument.length() > 0)
       {
-	CollationElement e = new CollationElement (sb.toString(), primary_seq,
+	CollationElement e = new CollationElement (argument.toString(), primary_seq,
 						   secondary_seq, tertiary_seq);
-	v.add (e);
+	vec.add (e);
       }
 
-    ce_table = v.toArray();
+    ce_table = vec.toArray();
   }
 
   /**
-   * This method returns a <code>String</code> containing the collation rules
-   * for this object.
+   * This method creates a copy of this object.
    *
-   * @return The collation rules for this object.
+   * @return A copy of this object.
    */
-  public String getRules()
+  public Object clone()
   {
-    return(rules);
-  }
-
-  /**
-   * This method calculates the collation element value for the specified
-   * character(s).
-   */
-  int getCollationElementValue(String str)
-  {
-    CollationElement e = null;
-
-    // The table is sorted.  Change to a binary search later.
-    for (int i = 0; i < ce_table.length; i++) 
-      if (((CollationElement)ce_table[i]).char_seq.equals(str))
-        {
-          e = (CollationElement)ce_table[i];
-          break;
-        }
-
-    if (e == null)
-      e = new CollationElement(str, 0xFFFF, (short)0xFF, (short)0xFF);
-
-    int retval = (e.primary << 16) + (e.secondary << 8) + e.tertiary;
-
-    return(retval);
-  }
-
-  /**
-   * This method returns an instance for <code>CollationElementIterator</code>
-   * for the specified <code>String</code> under the collation rules for this
-   * object.
-   *
-   * @param str The <code>String</code> to return the <code>CollationElementIterator</code> instance for.
-   *
-   * @return A <code>CollationElementIterator</code> for the specified <code>String</code>.
-   */
-  public CollationElementIterator getCollationElementIterator(String str)
-  {
-    return(new CollationElementIterator(this, str));
-  }  
-
-  /**
-   * This method returns an instance of <code>CollationElementIterator</code>
-   * for the <code>String</code> represented by the specified
-   * <code>CharacterIterator</code>.
-   *
-   * @param ci The <code>CharacterIterator</code> with the desired <code>String</code>.
-   *
-   * @return A <code>CollationElementIterator</code> for the specified <code>String</code>.
-   */
-  public CollationElementIterator getCollationElementIterator(CharacterIterator ci)
-  {
-    StringBuffer sb = new StringBuffer("");
-
-    // Right now we assume that we will read from the beginning of the string.
-    char c = ci.first();
-    while (c != CharacterIterator.DONE) 
-      {
-        sb.append(c);
-        c = ci.next();
-      }
-
-    return(getCollationElementIterator(sb.toString()));
+    RuleBasedCollator c = (RuleBasedCollator) super.clone ();
+    return c;
   }
 
   /**
@@ -371,121 +310,77 @@ public class RuleBasedCollator extends Collator
    * the second.  The value depends not only on the collation rules in
    * effect, but also the strength and decomposition settings of this object.
    *
-   * @param s1 The first <code>String</code> to compare.
-   * @param s2 A second <code>String</code> to compare to the first.
+   * @param source The first <code>String</code> to compare.
+   * @param target A second <code>String</code> to compare to the first.
    *
-   * @return A negative integer if s1 &lt; s2, a positive integer
-   * if s1 &gt; s2, or 0 if s1 == s2.
+   * @return A negative integer if source &lt; target, a positive integer
+   * if source &gt; target, or 0 if source == target.
    */
-  public int compare(String s1, String s2)
+  public int compare (String source, String target)
   {
-    CollationElementIterator cei1 = getCollationElementIterator(s1);
-    CollationElementIterator cei2 = getCollationElementIterator(s2);
+    CollationElementIterator cs = getCollationElementIterator (source);
+    CollationElementIterator ct = getCollationElementIterator (target);
 
-    for(;;)
+    while (true)
       {
-        int ord1 = cei1.next(); 
-        int ord2 = cei2.next(); 
-  
-        // Check for end of string
-        if (ord1 == CollationElementIterator.NULLORDER)
-          if (ord2 == CollationElementIterator.NULLORDER)
-            return(0);
-          else
-            return(-1);
-        else if (ord2 == CollationElementIterator.NULLORDER)
-          return(1);
+	int os = cs.next();
+	int ot = ct.next();
+
+	// Check for end of string
+	if (os == CollationElementIterator.NULLORDER
+	    && ot == CollationElementIterator.NULLORDER)
+	  {
+	    // Source and target string are equal.
+	    return 0;
+	  }
+	else if (os == CollationElementIterator.NULLORDER)
+	  {
+	    // Source string is shorter, so return "less than".
+	    return -1;
+	  }
+	else if (ot == CollationElementIterator.NULLORDER)
+	  {
+	    // Target string is shorter, so return "greater than".
+	    return 1;
+	  }
 
         // We know chars are totally equal, so skip
-        if (ord1 == ord2)
+        if (os == ot)
           continue;
 
         // Check for primary strength differences
-        int prim1 = cei1.primaryOrder(ord1); 
-        int prim2 = cei2.primaryOrder(ord2); 
+        int prim1 = cs.primaryOrder (os); 
+        int prim2 = ct.primaryOrder (ot); 
 
         if (prim1 < prim2)
-          return(-1);
+          return -1;
         else if (prim1 > prim2)
-          return(1);
+          return 1;
         else if (getStrength() == PRIMARY)
           continue;
 
         // Check for secondary strength differences
-        int sec1 = cei1.secondaryOrder(ord1);
-        int sec2 = cei2.secondaryOrder(ord2);
+        int sec1 = cs.secondaryOrder (os);
+        int sec2 = ct.secondaryOrder (ot);
 
         if (sec1 < sec2)
-          return(-1);
+          return -1;
         else if (sec1 > sec2)
-          return(1);
+          return 1;
         else if (getStrength() == SECONDARY)
           continue;
 
         // Check for tertiary differences
-        int tert1 = cei1.tertiaryOrder(ord1);
-        int tert2 = cei2.tertiaryOrder(ord1);
+        int tert1 = cs.tertiaryOrder (os);
+        int tert2 = ct.tertiaryOrder (ot);
 
         if (tert1 < tert2)
-          return(-1);
+          return -1;
         else if (tert1 > tert2)
-          return(1);
+          return 1;
       }
   }
 
-  /**
-   * This method returns an instance of <code>CollationKey</code> for the
-   * specified <code>String</code>.  The object returned will have a
-   * more efficient mechanism for its comparison function that could
-   * provide speed benefits if multiple comparisons are performed, such
-   * as during a sort.
-   *
-   * @param str The <code>String</code> to create a <code>CollationKey</code> for.
-   *
-   * @return A <code>CollationKey</code> for the specified <code>String</code>.
-   */
-  public CollationKey getCollationKey(String str)
-  {
-    CollationElementIterator cei = getCollationElementIterator(str);
-    Vector vect = new Vector(25);
-
-    int ord = cei.next();
-    cei.reset(); //set to start of string
-
-    while (ord != CollationElementIterator.NULLORDER)
-      {
-        switch (getStrength())
-          {
-            case PRIMARY:
-               ord = cei.primaryOrder(ord);
-               break;
-
-            case SECONDARY:
-               ord = cei.secondaryOrder(ord);
-
-            default:
-               break;
-          }
-
-        vect.add(new Integer(ord)); 
-	ord = cei.next(); //increment to next key
-      }
-
-    Object[] objarr = vect.toArray();
-    byte[] key = new byte[objarr.length * 4];
-
-    for (int i = 0; i < objarr.length; i++)
-      {
-        int j = ((Integer)objarr[i]).intValue();
-        key [i * 4] = (byte)((j & 0xFF000000) >> 24);
-        key [i * 4 + 1] = (byte)((j & 0x00FF0000) >> 16);
-        key [i * 4 + 2] = (byte)((j & 0x0000FF00) >> 8);
-        key [i * 4 + 3] = (byte)(j & 0x000000FF);
-      }
-
-    return(new CollationKey(this, str, key));
-  }
-
   /**
    * This method tests this object for equality against the specified 
    * object.  This will be true if and only if the specified object is
@@ -495,12 +390,112 @@ public class RuleBasedCollator extends Collator
    *
    * @return <code>true</code> if the specified object is equal to this object, <code>false</code> otherwise.
    */
-  public boolean equals(Object obj)
+  public boolean equals (Object obj)
   {
     if (obj == this)
-      return(true);
-    else
-      return(false);
+      return true;
+
+    return false;
+  }
+
+  /**
+   * This method returns an instance for <code>CollationElementIterator</code>
+   * for the specified <code>String</code> under the collation rules for this
+   * object.
+   *
+   * @param source The <code>String</code> to return the <code>CollationElementIterator</code> instance for.
+   *
+   * @return A <code>CollationElementIterator</code> for the specified <code>String</code>.
+   */
+  public CollationElementIterator getCollationElementIterator (String source)
+  {
+    return new CollationElementIterator (source, this);
+  }
+
+  /**
+   * This method returns an instance of <code>CollationElementIterator</code>
+   * for the <code>String</code> represented by the specified
+   * <code>CharacterIterator</code>.
+   *
+   * @param source The <code>CharacterIterator</code> with the desired <code>String</code>.
+   *
+   * @return A <code>CollationElementIterator</code> for the specified <code>String</code>.
+   */
+  public CollationElementIterator getCollationElementIterator (CharacterIterator source)
+  {
+    StringBuffer sb = new StringBuffer();
+
+    // Right now we assume that we will read from the beginning of the string.
+    for (char c = source.first(); c != CharacterIterator.DONE; c = source.next()) 
+      {
+        sb.append (c);
+      }
+
+    return getCollationElementIterator (sb.toString());
+  }
+
+  /**
+   * This method returns an instance of <code>CollationKey</code> for the
+   * specified <code>String</code>.  The object returned will have a
+   * more efficient mechanism for its comparison function that could
+   * provide speed benefits if multiple comparisons are performed, such
+   * as during a sort.
+   *
+   * @param source The <code>String</code> to create a <code>CollationKey</code> for.
+   *
+   * @return A <code>CollationKey</code> for the specified <code>String</code>.
+   */
+  public CollationKey getCollationKey (String source)
+  {
+    CollationElementIterator cei = getCollationElementIterator (source);
+    Vector vec = new Vector (25);
+
+    int ord = cei.next();
+    cei.reset(); //set to start of string
+
+    while (ord != CollationElementIterator.NULLORDER)
+      {
+        switch (getStrength())
+          {
+            case PRIMARY:
+               ord = cei.primaryOrder (ord);
+               break;
+
+            case SECONDARY:
+               ord = cei.secondaryOrder (ord);
+
+            default:
+               break;
+          }
+
+        vec.add (new Integer (ord)); 
+	ord = cei.next(); //increment to next key
+      }
+
+    Object[] objarr = vec.toArray();
+    byte[] key = new byte [objarr.length * 4];
+
+    for (int i = 0; i < objarr.length; i++)
+      {
+        int j = ((Integer) objarr [i]).intValue();
+        key [i * 4] = (byte) ((j & 0xFF000000) >> 24);
+        key [i * 4 + 1] = (byte) ((j & 0x00FF0000) >> 16);
+        key [i * 4 + 2] = (byte) ((j & 0x0000FF00) >> 8);
+        key [i * 4 + 3] = (byte) (j & 0x000000FF);
+      }
+
+    return new CollationKey (this, source, key);
+  }
+
+  /**
+   * This method returns a <code>String</code> containing the collation rules
+   * for this object.
+   *
+   * @return The collation rules for this object.
+   */
+  public String getRules()
+  {
+    return rules;
   }
 
   /**
@@ -510,16 +505,31 @@ public class RuleBasedCollator extends Collator
    */
   public int hashCode()
   {
-    return(System.identityHashCode(this));
+    return System.identityHashCode (this);
   }
 
   /**
-   * This method creates a copy of this object.
-   *
-   * @return A copy of this object.
+   * This method calculates the collation element value for the specified
+   * character(s).
    */
-  public Object clone()
+  int getCollationElementValue (String source)
   {
-    return super.clone();
+    CollationElement e = null;
+
+    // The table is sorted.  Change to a binary search later.
+    for (int i = 0; i < ce_table.length; i++) 
+      if (((CollationElement) ce_table [i]).char_seq.equals (source))
+        {
+          e = (CollationElement) ce_table [i];
+          break;
+        }
+
+    if (e == null)
+      e = new CollationElement (source, 0xFFFF, (short)0xFF, (short)0xFF);
+
+    int retval = (e.primary << 16) + (e.secondary << 8) + e.tertiary;
+
+    return retval;
   }
-}
+
+} // class RuleBaseCollator
